% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsrvfl.R
\name{tsrvflf}
\alias{tsrvflf}
\title{Fit and forecast a time series using RVFL}
\usage{
tsrvflf(
  y,
  h = 5,
  lags = 15L,
  engine = stats::lm,
  level = 95,
  n_hidden_features = 5L,
  nodes_sim = c("sobol", "halton", "unif"),
  activ = c("relu", "sigmoid", "tanh", "leakyrelu", "elu", "linear"),
  type_pi = c("surrogate", "kde", "bootstrap"),
  B = 250L,
  agg = c("mean", "median"),
  seed = 123,
  coeffs = NULL,
  ...
)
}
\arguments{
\item{y}{A numeric vector or time series of the response variable.}

\item{h}{The number of steps ahead to forecast.}

\item{lags}{The number of lags to use in the model.}

\item{engine}{The engine to use for the model fitting.}

\item{level}{The confidence level for the prediction intervals.}

\item{n_hidden_features}{The number of hidden features to use in the model.}

\item{nodes_sim}{The method to use for simulating nodes.}

\item{activ}{The activation function to use in the model.}

\item{type_pi}{The type of prediction interval to use.}

\item{B}{The number of bootstrap samples to use.}

\item{agg}{The aggregation function to use.}

\item{seed}{The random seed to use.}

\item{coeffs}{The coefficients to use in the model.}
}
\value{
An object of class "forecast" containing the fitted model and forecasts
}
\description{
This function combines model fitting using tsrvfl() and forecasting in one step.
It's a convenience wrapper that fits a model and immediately generates forecasts.
}
\examples{
y <- ts(rnorm(120,0,3) + 1:120 + 20*sin(2*pi*(1:120)/12), frequency=12)
fit <- tsrvflf(y, h=20)
plot(fit)

}
